@@ -420,7 +420,7 @@ char *read_solution_banner_and_string ( FILE *fp, int k, int *len, int *dim );
  *   and the number of variables in dim. */
 
 int varbprec_Newton_Laurent_step
- ( int dim, int wanted, int maxitr, int maxprc, int ns, char *s );
+ ( int dim, int wanted, int maxitr, int maxprc, int ns, const char *s );
 /*
  * DESCRIPTION :
  *   Replaces the solutions in the multprecision solutions container with
@@ -443,7 +443,7 @@ int read_standard_target_system ( void );
  *   Prompts the user for a file name and reads the target system from file.
  *   If available on file, also its solutions will be read and stored. */
 
-int read_standard_target_system_from_file ( int n, char *filename );
+int read_standard_target_system_from_file ( int n, const char *filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -457,7 +457,7 @@ int read_dobldobl_target_system ( void );
  *   If available on file, also its solutions will be read and stored.
  *   All data is parsed to double double precision. */
 
-int read_dobldobl_target_system_from_file ( int n, char* filename );
+int read_dobldobl_target_system_from_file ( int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -471,7 +471,7 @@ int read_quaddobl_target_system ( void );
  *   If available on file, also its solutions will be read and stored.
  *   All data is parsed to quad double precision. */
 
-int read_quaddobl_target_system_from_file ( int n, char* filename );
+int read_quaddobl_target_system_from_file ( int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -487,7 +487,7 @@ int read_multprec_target_system ( int decimals );
  *   places as the value of decimals. */
 
 int read_multprec_target_system_from_file
-  ( int decimals, int n, char* filename );
+  ( int decimals, int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -522,7 +522,7 @@ int read_standard_start_system ( void );
  *   Prompts the user for a file name and reads the start system from file. 
  *   If available, then also start solutions will be read and stored. */
 
-int read_standard_start_system_from_file ( int n, char* filename );
+int read_standard_start_system_from_file ( int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -537,7 +537,7 @@ int read_dobldobl_start_system ( void );
  *   If available, then also start solutions will be read and stored.
  *   All data is parsed to double double precision. */
 
-int read_dobldobl_start_system_from_file ( int n, char* filename );
+int read_dobldobl_start_system_from_file ( int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -552,7 +552,7 @@ int read_quaddobl_start_system ( void );
  *   If available, then also start solutions will be read and stored.
  *   All data is parsed to quad double precision. */
 
-int read_quaddobl_start_system_from_file ( int n, char* filename );
+int read_quaddobl_start_system_from_file ( int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
@@ -569,7 +569,7 @@ int read_multprec_start_system ( int decimals );
  *   places as the value of decimals. */
 
 int read_multprec_start_system_from_file
- ( int decimals, int n, char* filename );
+ ( int decimals, int n, const char* filename );
 /*
  * DESCRIPTION :
  *   Opens the file with name given in the n characters stored in filename,
