@@ -528,6 +528,27 @@ void CPU_dbl8_evaldiff
          outputhilohi[dim],outputlolohi[dim],
          outputhihilo[dim],outputlohilo[dim],
          outputhilolo[dim],outputlololo[dim]);
+      // CPU_dbl8_product(deg,
+      //    outputhihihi[dim],outputlohihi[dim],
+      //    outputhilohi[dim],outputlolohi[dim],
+      //    outputhihilo[dim],outputlohilo[dim],
+      //    outputhilolo[dim],outputlololo[dim],
+      //    cffhihihi,cfflohihi,cffhilohi,cfflolohi,
+      //    cffhihilo,cfflohilo,cffhilolo,cfflololo,
+      //    outputhihihi[dim],outputlohihi[dim],
+      //    outputhilohi[dim],outputlolohi[dim],
+      //    outputhihilo[dim],outputlohilo[dim],
+      //    outputhilolo[dim],outputlololo[dim]); // wrong!
+
+      double *acchihihi = new double[deg+1];
+      double *acclohihi = new double[deg+1];
+      double *acchilohi = new double[deg+1];
+      double *acclolohi = new double[deg+1];
+      double *acchihilo = new double[deg+1];
+      double *acclohilo = new double[deg+1];
+      double *acchilolo = new double[deg+1];
+      double *acclololo = new double[deg+1];
+
       CPU_dbl8_product(deg,
          outputhihihi[dim],outputlohihi[dim],
          outputhilohi[dim],outputlolohi[dim],
@@ -535,10 +556,24 @@ void CPU_dbl8_evaldiff
          outputhilolo[dim],outputlololo[dim],
          cffhihihi,cfflohihi,cffhilohi,cfflolohi,
          cffhihilo,cfflohilo,cffhilolo,cfflololo,
-         outputhihihi[dim],outputlohihi[dim],
-         outputhilohi[dim],outputlolohi[dim],
-         outputhihilo[dim],outputlohilo[dim],
-         outputhilolo[dim],outputlololo[dim]);
+         acchihihi,acclohihi,acchilohi,acclolohi,
+         acchihilo,acclohilo,acchilolo,acclololo);
+
+      for(int i=0; i<=deg; i++)
+      {
+         outputhihihi[dim][i] = acchihihi[i];
+         outputlohihi[dim][i] = acclohihi[i];
+         outputhilohi[dim][i] = acchilohi[i];
+         outputlolohi[dim][i] = acclolohi[i];
+         outputhihilo[dim][i] = acchihilo[i];
+         outputlohilo[dim][i] = acclohilo[i];
+         outputhilolo[dim][i] = acchilolo[i];
+         outputlololo[dim][i] = acclololo[i];
+      }
+      free(acchihihi); free(acclohihi);
+      free(acchilohi); free(acclolohi);
+      free(acchihilo); free(acclohilo);
+      free(acchilolo); free(acclololo);
 
       CPU_dbl8_product(deg,
          cffhihihi,cfflohihi,cffhilohi,cfflolohi,
@@ -842,6 +877,7 @@ void CPU_cmplx8_evaldiff
          outputimhilohi[dim],outputimlolohi[dim],
          outputimhihilo[dim],outputimlohilo[dim],
          outputimhilolo[dim],outputimlololo[dim]);
+ /*
       CPU_cmplx8_product(deg,
          outputrehihihi[dim],outputrelohihi[dim],
          outputrehilohi[dim],outputrelolohi[dim],
@@ -863,6 +899,70 @@ void CPU_cmplx8_evaldiff
          outputimhilohi[dim],outputimlolohi[dim],
          outputimhihilo[dim],outputimlohilo[dim],
          outputimhilolo[dim],outputimlololo[dim]);
+  */
+
+      double *accrehihihi = new double[deg+1];
+      double *accrelohihi = new double[deg+1];
+      double *accrehilohi = new double[deg+1];
+      double *accrelolohi = new double[deg+1];
+      double *accrehihilo = new double[deg+1];
+      double *accrelohilo = new double[deg+1];
+      double *accrehilolo = new double[deg+1];
+      double *accrelololo = new double[deg+1];
+      double *accimhihihi = new double[deg+1];
+      double *accimlohihi = new double[deg+1];
+      double *accimhilohi = new double[deg+1];
+      double *accimlolohi = new double[deg+1];
+      double *accimhihilo = new double[deg+1];
+      double *accimlohilo = new double[deg+1];
+      double *accimhilolo = new double[deg+1];
+      double *accimlololo = new double[deg+1];
+
+      CPU_cmplx8_product(deg,
+         outputrehihihi[dim],outputrelohihi[dim],
+         outputrehilohi[dim],outputrelolohi[dim],
+         outputrehihilo[dim],outputrelohilo[dim],
+         outputrehilolo[dim],outputrelololo[dim],
+         outputimhihihi[dim],outputimlohihi[dim],
+         outputimhilohi[dim],outputimlolohi[dim],
+         outputimhihilo[dim],outputimlohilo[dim],
+         outputimhilolo[dim],outputimlololo[dim],
+         cffrehihihi,cffrelohihi,cffrehilohi,cffrelolohi,
+         cffrehihilo,cffrelohilo,cffrehilolo,cffrelololo,
+         cffimhihihi,cffimlohihi,cffimhilohi,cffimlolohi,
+         cffimhihilo,cffimlohilo,cffimhilolo,cffimlololo,
+         accrehihihi,accrelohihi,accrehilohi,accrelolohi,
+         accrehihilo,accrelohilo,accrehilolo,accrelololo,
+         accimhihihi,accimlohihi,accimhilohi,accimlolohi,
+         accimhihilo,accimlohilo,accimhilolo,accimlololo);
+
+      for(int i=0; i<=deg; i++)
+      {
+         outputrehihihi[dim][i] = accrehihihi[i];
+         outputrelohihi[dim][i] = accrelohihi[i];
+         outputrehilohi[dim][i] = accrehilohi[i];
+         outputrelolohi[dim][i] = accrelolohi[i];
+         outputrehihilo[dim][i] = accrehihilo[i];
+         outputrelohilo[dim][i] = accrelohilo[i];
+         outputrehilolo[dim][i] = accrehilolo[i];
+         outputrelololo[dim][i] = accrelololo[i];
+         outputimhihihi[dim][i] = accimhihihi[i];
+         outputimlohihi[dim][i] = accimlohihi[i];
+         outputimhilohi[dim][i] = accimhilohi[i];
+         outputimlolohi[dim][i] = accimlolohi[i];
+         outputimhihilo[dim][i] = accimhihilo[i];
+         outputimlohilo[dim][i] = accimlohilo[i];
+         outputimhilolo[dim][i] = accimhilolo[i];
+         outputimlololo[dim][i] = accimlololo[i];
+      }
+      free(accrehihihi); free(accrelohihi); 
+      free(accrehilohi); free(accrelolohi);
+      free(accrehihilo); free(accrelohilo); 
+      free(accrehilolo); free(accrelololo);
+      free(accimhihihi); free(accimlohihi);
+      free(accimhilohi); free(accimlolohi);
+      free(accimhihilo); free(accimlohilo);
+      free(accimhilolo); free(accimlololo);
 
       CPU_cmplx8_product(deg,
          cffrehihihi,cffrelohihi,cffrehilohi,cffrelolohi,
@@ -894,10 +994,10 @@ void CPU_cmplx8_evaldiff
          inputrehilohi[ix2],inputrelolohi[ix2],
          inputrehihilo[ix2],inputrelohilo[ix2],
          inputrehilolo[ix2],inputrelololo[ix2],
-         inputimhihihi[ix1],inputimlohihi[ix1],
-         inputimhilohi[ix1],inputimlolohi[ix1],
-         inputimhihilo[ix1],inputimlohilo[ix1],
-         inputimhilolo[ix1],inputimlololo[ix1],
+         inputimhihihi[ix2],inputimlohihi[ix2],
+         inputimhilohi[ix2],inputimlolohi[ix2],
+         inputimhihilo[ix2],inputimlohilo[ix2],
+         inputimhilolo[ix2],inputimlololo[ix2],
          outputrehihihi[ix1],outputrelohihi[ix1],
          outputrehilohi[ix1],outputrelolohi[ix1],
          outputrehihilo[ix1],outputrelohilo[ix1],
