@@ -4,6 +4,53 @@
 #ifndef __random8_series_h__
 #define __random8_series_h__
 
+void dbl8_exponential
+ ( int deg, double xhihihi, double xlohihi, double xhilohi, double xlolohi,
+            double xhihilo, double xlohilo, double xhilolo, double xlololo,
+   double *shihihi, double *slohihi, double *shilohi, double *slolohi,
+   double *shihilo, double *slohilo, double *shilolo, double *slololo );
+/*
+ * DESCRIPTION :
+ *   Returns power series truncated at degree deg,
+ *   following the expansion of exp(x).
+ *
+ * ON ENTRY :
+ *   deg      degree to truncate the series;
+ *   xhihihi  highest double of x;
+ *   xlohihi  second highest double of x;
+ *   xhilohi  third highest double of x;
+ *   xlolohi  fourth highest double of x;
+ *   xhihilo  fourth lowest double of x;
+ *   xlohilo  third lowest double of x;
+ *   xhilolo  second lowest double of x;
+ *   xlololo  lowest double of x;
+ *   shihihi  space for deg+1 doubles;
+ *   slohihi  space for deg+1 doubles;
+ *   shilohi  space for deg+1 doubles;
+ *   slolohi  space for deg+1 doubles;
+ *   shihilo  space for deg+1 doubles;
+ *   slohilo  space for deg+1 doubles;
+ *   shilolo  space for deg+1 doubles;
+ *   slololo  space for deg+1 doubles.
+ *
+ * ON RETURN :
+ *   shihihi  highest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   slohihi  second highest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   shilohi  third highest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   slolohi  fourth highest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   shihilo  fourth lowest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   slohilo  third lowest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   shilolo  second lowest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg;
+ *   slololo  lowest doubles of the coefficients of series
+ *            following exp(x), truncated to degree deg. */
+
 void dbl8_exponentials
  ( int deg, double xhihihi, double xlohihi, double xhilohi, double xlolohi, 
             double xhihilo, double xlohilo, double xhilolo, double xlololo, 
@@ -79,6 +126,18 @@ void dbl8_exponentials
  *   minxhilolo   second lowest doubles of the series of exp(-x);
  *   minxlololo   lowest doubles of the series of exp(-x). */
 
+void random_dbl8_exponential
+ ( int deg,
+   double *xhihihi, double *xlohihi, double *xhilohi, double *xlolohi,
+   double *xhihilo, double *xlohilo, double *xhilolo, double *xlololo,
+   double *shihihi, double *slohihi, double *shilohi, double *slolohi,
+   double *shihilo, double *slohilo, double *shilolo, double *slololo );
+/*
+ * DESCRIPTION :
+ *   Returns a power series truncated at degree deg
+ *   for a randomly generated octo double x,
+ *   following the expansion of exp(x). */
+
 void random_dbl8_exponentials
  ( int deg,
    double *xhihihi, double *xlohihi, double *xhilohi, double *xlolohi,
@@ -97,6 +156,90 @@ void random_dbl8_exponentials
  *   except that xhihihi, xlohihi, xhilohi, xlolohi,
  *   xhihilo, xlohilo, xhilolo, and xlololo are return parameters. */
 
+void cmplx8_exponential
+ ( int deg,
+   double xrehihihi, double xrelohihi, double xrehilohi, double xrelolohi, 
+   double xrehihilo, double xrelohilo, double xrehilolo, double xrelololo, 
+   double ximhihihi, double ximlohihi, double ximhilohi, double ximlolohi,
+   double ximhihilo, double ximlohilo, double ximhilolo, double ximlololo,
+   double *srehihihi, double *srelohihi, double *srehilohi, double *srelolohi,
+   double *srehihilo, double *srelohilo, double *srehilolo, double *srelololo,
+   double *simhihihi, double *simlohihi, double *simhilohi, double *simlolohi,
+   double *simhihilo, double *simlohilo, double *simhilolo, double *simlololo );
+/*
+ * DESCRIPTION :
+ *   Returns power series truncated at degree deg,
+ *   following the expansion of exp(x).
+ *
+ * ON ENTRY :
+ *   deg      degree to truncate the series;
+ *   xrehihihi is the highest double of the real part of x;
+ *   xrelohihi is the second highest double of the real part of x;
+ *   xrehilohi is the third highest double of the real part of x;
+ *   xrelolohi is the fourth highest double of the real part of x;
+ *   xrehihilo is the fourth lowest double of the real part of x;
+ *   xrelohilo is the third lowest double of the real part of x;
+ *   xrehilolo is the second lowest double of the real part of x;
+ *   xrelololo is the lowest double of the real part of x;
+ *   ximhihihi is the highest double of the imaginary part of x;
+ *   ximlohihi is the second highest double of the imaginary part of x;
+ *   ximhilohi is the third highest double of the imaginary part of x;
+ *   ximlolohi is the fourth highest double of the imaginary part of x;
+ *   ximhihilo is the fourth lowest double of the imaginary part of x;
+ *   ximlohilo is the third lowest double of the imaginary part of x;
+ *   ximhilolo is the second lowest double of the imaginary part of x;
+ *   ximlololo is the lowest double of the imaginary part of x;
+ *   srehihihi has space for deg+1 doubles;
+ *   srelohihi has space for deg+1 doubles;
+ *   srehilohi has space for deg+1 doubles;
+ *   srelolohi has space for deg+1 doubles;
+ *   srehihilo has space for deg+1 doubles;
+ *   srelohilo has space for deg+1 doubles;
+ *   srehilolo has space for deg+1 doubles;
+ *   srelololo has space for deg+1 doubles;
+ *   simhihihi has space for deg+1 doubles;
+ *   simlohihi has space for deg+1 doubles;
+ *   simhilohi has space for deg+1 doubles;
+ *   simlolohi has space for deg+1 doubles.
+ *   simhihilo has space for deg+1 doubles;
+ *   simlohilo has space for deg+1 doubles;
+ *   simhilolo has space for deg+1 doubles;
+ *   simlololo has space for deg+1 doubles.
+ *
+ * ON RETURN :
+ *   srehihihi are the highest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srelohihi are the second highest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srehilohi are the third highest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srelolohi are the fourth highest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srehihilo are the fourth lowest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srelohilo are the third lowest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srehilolo are the second lowest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   srelololo are the lowest doubles of the real parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simhihihi are the highest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simlohihi are the second highest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simhilohi are the third highest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simlolohi are the fourth highest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simhihilo are the fourth lowest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simlohilo are the third lowest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simhilolo are the second lowest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg;
+ *   simlololo are the lowest doubles of the imaginary parts of series
+ *            following exp(x), truncated to degree deg. */
+
 void cmplx8_exponentials
  ( int deg,
    double xrehihihi, double xrelohihi, double xrehilohi, double xrelolohi,
@@ -279,6 +422,22 @@ void cmplx8_exponentials
  *   minximlololo  lowest doubles of the imaginary parts of the exp(-x) series
  *                 truncated to degree deg. */
 
+void random_cmplx8_exponential
+ ( int deg,
+   double *xrehihihi, double *xrelohihi, double *xrehilohi, double *xrelolohi,
+   double *xrehihilo, double *xrelohilo, double *xrehilolo, double *xrelololo,
+   double *ximhihihi, double *ximlohihi, double *ximhilohi, double *ximlolohi,
+   double *ximhihilo, double *ximlohilo, double *ximhilolo, double *ximlololo,
+   double *srehihihi, double *srelohihi, double *srehilohi, double *srelolohi,
+   double *srehihilo, double *srelohilo, double *srehilolo, double *srelololo,
+   double *simhihihi, double *simlohihi, double *simhilohi, double *simlolohi,
+   double *simhihilo, double *simlohilo, double *simhilolo, double *simlololo );
+/*
+ * DESCRIPTION :
+ *   Returns power series following the expansion of exp(x),
+ *   for a complex x, with randomly generated real and imaginary parts
+ *   returned in xre and xim, truncated at degree deg. */
+
 void random_cmplx8_exponentials
  ( int deg, 
    double *xrehihihi, double *xrelohihi, double *xrehilohi, double *xrelolohi,
