@@ -13,6 +13,8 @@
 #include "dbl2_tabs_kernels.h"
 #include "dbl_test_utilities.h"
 #include "dbl2_test_utilities.h"
+#include "write_dbl2_bstimeflops.h"
+#include "dbl_tabs_testers.h"
 #include "dbl_data_files.h"
 
 using namespace std;
@@ -535,45 +537,10 @@ void test_real2_upper_tiling ( void )
    cout << fixed << setprecision(3);
    cout << "Elapsed CPU time (Linux), Wall time (Windows) : "
         << timelapsed_h << " seconds." << endl;
-   cout << "          Time spent to invert diagonal tiles : ";
-   cout << invlapsed << " milliseconds." << endl;
-   cout << "   Time spent to multiply with inverted tiles : ";
-   cout << mullapsed << " milliseconds." << endl;
-   cout << "             Time spent for back substitution : ";
-   cout << sublapsed << " milliseconds." << endl;
-   cout << "                    Time spent by all kernels : ";
-   cout << elapsedms << " milliseconds." << endl;
-   cout << "        Total GPU wall clock computation time : ";
-   cout << fixed << setprecision(3) << timelapsed_d << " seconds." << endl;
-   cout << endl;
-   cout << "             Number of additions/subtractions : "
-        << addcnt << " x 20 " << endl;
-   cout << "                    Number of multiplications : "
-        << mulcnt << " x 23 " << endl;
-   cout << "                          Number of divisions : "
-        << divcnt << " x 70 " << endl;
-   long long int flopcnt = 20*addcnt + 23*mulcnt + 70*divcnt;
-   cout << "    Total number of floating-point operations : "
-        << flopcnt << endl;
-   cout << endl;
-   long long int bytecnt = 4*sizetile*numtiles*(numtiles+1)*2
-                         + 8*sizetile*numtiles*2;
-   cout << "    Total number of bytes : " << bytecnt << endl << endl;
-   double intensity = ((double) flopcnt)/bytecnt;
-   cout << "     Arithmetic intensity : "
-        << scientific << setprecision(3) << intensity
-        << " #flops/#bytes" << endl << endl;
-   double kernflops = 1000.0*((double) flopcnt)/elapsedms;
-   double wallflops = ((double) flopcnt)/timelapsed_d;
-   const int gigacnt = pow(2.0,30);
-   cout << "Kernel Time Flops : "
-        << scientific << setprecision(3) << kernflops;
-   cout << fixed << setprecision(3)
-        << " = " << kernflops/gigacnt << " Gigaflops" << endl;
-   cout << " Wall Clock Flops : "
-        << scientific << setprecision(3) << wallflops;
-   cout << fixed << setprecision(3)
-        << " = " << wallflops/gigacnt << " Gigaflops" << endl;
+
+   write_dbl2_bstimeflops
+     (sizetile,numtiles,0,invlapsed,mullapsed,sublapsed,elapsedms,
+      timelapsed_d,addcnt,mulcnt,divcnt);
 
    for(int i=0; i<dim; i++)
    {
@@ -821,45 +788,10 @@ void test_cmplx2_upper_tiling ( void )
    cout << fixed << setprecision(3);
    cout << "Elapsed CPU time (Linux), Wall time (Windows) : "
         << timelapsed_h << " seconds." << endl;
-   cout << "          Time spent to invert diagonal tiles : ";
-   cout << invlapsed << " milliseconds." << endl;
-   cout << "   Time spent to multiply with inverted tiles : ";
-   cout << mullapsed << " milliseconds." << endl;
-   cout << "             Time spent for back substitution : ";
-   cout << sublapsed << " milliseconds." << endl;
-   cout << "                    Time spent by all kernels : ";
-   cout << elapsedms << " milliseconds." << endl;
-   cout << "        Total GPU wall clock computation time : ";
-   cout << fixed << setprecision(3) << timelapsed_d << " seconds." << endl;
-   cout << endl;
-   cout << "             Number of additions/subtractions : "
-        << addcnt << " x 20 " << endl;
-   cout << "                    Number of multiplications : "
-        << mulcnt << " x 23 " << endl;
-   cout << "                          Number of divisions : "
-        << divcnt << " x 70 " << endl;
-   long long int flopcnt = 20*addcnt + 23*mulcnt + 70*divcnt;
-   cout << "    Total number of floating-point operations : "
-        << flopcnt << endl;
-   cout << endl;
-   long long int bytecnt = 4*sizetile*numtiles*(numtiles+1)*4
-                         + 8*sizetile*numtiles*4;
-   cout << "    Total number of bytes : " << bytecnt << endl << endl;
-   double intensity = ((double) flopcnt)/bytecnt;
-   cout << "     Arithmetic intensity : "
-        << scientific << setprecision(3) << intensity
-        << " #flops/#bytes" << endl << endl;
-   double kernflops = 1000.0*((double) flopcnt)/elapsedms;
-   double wallflops = ((double) flopcnt)/timelapsed_d;
-   const int gigacnt = pow(2.0,30);
-   cout << "Kernel Time Flops : "
-        << scientific << setprecision(3) << kernflops;
-   cout << fixed << setprecision(3)
-        << " = " << kernflops/gigacnt << " Gigaflops" << endl;
-   cout << " Wall Clock Flops : "
-        << scientific << setprecision(3) << wallflops;
-   cout << fixed << setprecision(3)
-        << " = " << wallflops/gigacnt << " Gigaflops" << endl;
+
+   write_dbl2_bstimeflops
+     (sizetile,numtiles,1,invlapsed,mullapsed,sublapsed,elapsedms,
+      timelapsed_d,addcnt,mulcnt,divcnt);
 
    for(int i=0; i<dim; i++)
    {
