@@ -1,11 +1,11 @@
 # standalone test on setting a system
-include("JuPHC.jl")
+include("PHCpack.jl")
 verbose = 10
 polynomials = ["x^3 + 2*x*y - 1;", "x + y - 1;"]
-JuPHC.setDoubleSystem(2, polynomials, verbose)
-dim = JuPHC.getDoubleDimension(verbose)
+PHCpack.setDoubleSystem(2, polynomials, verbose)
+dim = PHCpack.getDoubleDimension(verbose)
 println("the dimension : ", dim)
-pols = JuPHC.getDoubleSystem(verbose)
+pols = PHCpack.getDoubleSystem(verbose)
 println("the polynomials :")
 for pol in pols
     println(pol)
