@@ -10,13 +10,15 @@ Given a witness set and a point, a homotopy membership determines whether
 the point belongs to the solution set represented by the witness set.
 """
 
-def standard_embed(nvar, topdim, pols):
+def standard_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings representing polynomials in *nvar*
     variables, with coefficients in standard double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_standard_system
     from phcpy.interface import store_standard_system, load_standard_system
@@ -24,13 +26,15 @@ def standard_embed(nvar, topdim, pols):
     py2c_embed_standard_system(topdim)
     return load_standard_system()
 
-def dobldobl_embed(nvar, topdim, pols):
+def dobldobl_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in *nvar*
     variables, with coefficients in double double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_dobldobl_system
     from phcpy.interface import store_dobldobl_system, load_dobldobl_system
@@ -38,13 +42,15 @@ def dobldobl_embed(nvar, topdim, pols):
     py2c_embed_dobldobl_system(topdim)
     return load_dobldobl_system()
 
-def quaddobl_embed(nvar, topdim, pols):
+def quaddobl_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in n*var*
     variables, with coefficients in quad double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_quaddobl_system
     from phcpy.interface import store_quaddobl_system, load_quaddobl_system
@@ -52,13 +58,15 @@ def quaddobl_embed(nvar, topdim, pols):
     py2c_embed_quaddobl_system(topdim)
     return load_quaddobl_system()
 
-def standard_laurent_embed(nvar, topdim, pols):
+def standard_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings representing Laurent polynomials
     in *nvar* variables, with coefficients in standard double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_standard_Laurent_system
     from phcpy.interface import store_standard_laurent_system
@@ -67,13 +75,15 @@ def standard_laurent_embed(nvar, topdim, pols):
     py2c_embed_standard_Laurent_system(topdim)
     return load_standard_laurent_system()
 
-def dobldobl_laurent_embed(nvar, topdim, pols):
+def dobldobl_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials
     in *nvar* variables, with coefficients in double double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_dobldobl_Laurent_system
     from phcpy.interface import store_dobldobl_laurent_system
@@ -82,13 +92,15 @@ def dobldobl_laurent_embed(nvar, topdim, pols):
     py2c_embed_dobldobl_Laurent_system(topdim)
     return load_dobldobl_laurent_system()
 
-def quaddobl_laurent_embed(nvar, topdim, pols):
+def quaddobl_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials
     in n*var* variables, with coefficients in quad double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     from phcpy.phcpy2c2 import py2c_embed_quaddobl_Laurent_system
     from phcpy.interface import store_quaddobl_laurent_system
@@ -97,7 +109,7 @@ def quaddobl_laurent_embed(nvar, topdim, pols):
     py2c_embed_quaddobl_Laurent_system(topdim)
     return load_quaddobl_laurent_system()
 
-def embed(nvar, topdim, pols, precision='d'):
+def embed(nvar, topdim, pols, precision='d', verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in *nvar*
     variables, this function returns an embedding 
@@ -107,18 +119,20 @@ def embed(nvar, topdim, pols, precision='d'):
     The default precision of the coefficients is 'd', for standard double
     precision.  For double double and quad double precision, set the value
     of precision to 'dd' or 'qd' respectively.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     if(precision == 'd'):
-        return standard_embed(nvar, topdim, pols)
+        return standard_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'dd'):
-        return dobldobl_embed(nvar, topdim, pols)
+        return dobldobl_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'qd'):
-        return quaddobl_embed(nvar, topdim, pols)
+        return quaddobl_embed(nvar, topdim, pols, verbose_level)
     else:
         print 'wrong argument for precision'
         return None
 
-def laurent_embed(nvar, topdim, pols, precision='d'):
+def laurent_embed(nvar, topdim, pols, precision='d', verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials
     in *nvar* variables, this function returns an embedding 
@@ -128,13 +142,15 @@ def laurent_embed(nvar, topdim, pols, precision='d'):
     The default precision of the coefficients is 'd', for standard double
     precision.  For double double and quad double precision, set the value
     of precision to 'dd' or 'qd' respectively.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     if(precision == 'd'):
-        return standard_laurent_embed(nvar, topdim, pols)
+        return standard_laurent_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'dd'):
-        return dobldobl_laurent_embed(nvar, topdim, pols)
+        return dobldobl_laurent_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'qd'):
-        return quaddobl_laurent_embed(nvar, topdim, pols)
+        return quaddobl_laurent_embed(nvar, topdim, pols, verbose_level)
     else:
         print 'wrong argument for precision'
         return None
