@@ -10,94 +10,106 @@ Given a witness set and a point, a homotopy membership determines whether
 the point belongs to the solution set represented by the witness set.
 """
 
-def standard_embed(nvar, topdim, pols):
+def standard_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings representing polynomials in *nvar*
     variables, with coefficients in standard double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_standard_system
     from phcpy.interface import store_standard_system, load_standard_system
     store_standard_system(pols, nbvar=nvar)
-    py2c_embed_standard_system(topdim)
+    py2c_embed_standard_system(topdim,verbose_level)
     return load_standard_system()
 
-def dobldobl_embed(nvar, topdim, pols):
+def dobldobl_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in *nvar*
     variables, with coefficients in double double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_dobldobl_system
     from phcpy.interface import store_dobldobl_system, load_dobldobl_system
     store_dobldobl_system(pols, nbvar=nvar)
-    py2c_embed_dobldobl_system(topdim)
+    py2c_embed_dobldobl_system(topdim,verbose_level)
     return load_dobldobl_system()
 
-def quaddobl_embed(nvar, topdim, pols):
+def quaddobl_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in *nvar*
     variables, with coefficients in quad double precision,
     this function returns an embedding of *pols* of dimension topdim.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_quaddobl_system
     from phcpy.interface import store_quaddobl_system, load_quaddobl_system
     store_quaddobl_system(pols, nbvar=nvar)
-    py2c_embed_quaddobl_system(topdim)
+    py2c_embed_quaddobl_system(topdim,verbose_level)
     return load_quaddobl_system()
 
-def standard_laurent_embed(nvar, topdim, pols):
+def standard_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings representing Laurent polynomials 
     in *nvar* variables, with coefficients in standard double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_standard_Laurent_system
     from phcpy.interface import store_standard_laurent_system
     from phcpy.interface import load_standard_laurent_system
     store_standard_laurent_system(pols, nbvar=nvar)
-    py2c_embed_standard_Laurent_system(topdim)
+    py2c_embed_standard_Laurent_system(topdim,verbose_level)
     return load_standard_laurent_system()
 
-def dobldobl_laurent_embed(nvar, topdim, pols):
+def dobldobl_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials 
     in *nvar* variables, with coefficients in double double precision,
     this function returns an embedding of *pols* of dimension *topdim*.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_dobldobl_Laurent_system
     from phcpy.interface import store_dobldobl_laurent_system
     from phcpy.interface import load_dobldobl_laurent_system
     store_dobldobl_laurent_system(pols, nbvar=nvar)
-    py2c_embed_dobldobl_Laurent_system(topdim)
+    py2c_embed_dobldobl_Laurent_system(topdim,verbose_level)
     return load_dobldobl_laurent_system()
 
-def quaddobl_laurent_embed(nvar, topdim, pols):
+def quaddobl_laurent_embed(nvar, topdim, pols, verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials 
     in *nvar* variables, with coefficients in quad double precision,
     this function returns an embedding of *pols* of dimension topdim.
     The *topdim* is the top dimension which equals the expected highest
     dimension of a component of the solution set of the system of polynomials.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the blackbox solver will be listed.
     """
     from phcpy.phcpy2c3 import py2c_embed_quaddobl_Laurent_system
     from phcpy.interface import store_quaddobl_laurent_system
     from phcpy.interface import load_quaddobl_laurent_system
     store_quaddobl_laurent_system(pols, nbvar=nvar)
-    py2c_embed_quaddobl_Laurent_system(topdim)
+    py2c_embed_quaddobl_Laurent_system(topdim,verbose_level)
     return load_quaddobl_laurent_system()
 
-def embed(nvar, topdim, pols, precision='d'):
+def embed(nvar, topdim, pols, precision='d', verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent polynomials in *nvar*
     variables, this function returns an embedding of *pols* 
@@ -107,18 +119,20 @@ def embed(nvar, topdim, pols, precision='d'):
     The default *precision* of the coefficients is 'd', for standard double
     precision.  For double double and quad double precision, set the value
     of *precision* to 'dd' or 'qd' respectively.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     if(precision == 'd'):
-        return standard_embed(nvar, topdim, pols)
+        return standard_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'dd'):
-        return dobldobl_embed(nvar, topdim, pols)
+        return dobldobl_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'qd'):
-        return quaddobl_embed(nvar, topdim, pols)
+        return quaddobl_embed(nvar, topdim, pols, verbose_level)
     else:
         print('wrong argument for precision')
         return None
 
-def laurent_embed(nvar, topdim, pols, precision='d'):
+def laurent_embed(nvar, topdim, pols, precision='d', verbose_level=0):
     r"""
     Given in *pols* a list of strings that represent Laurent polynomials
     in *nvar* variables, this function returns an embedding of *pols* 
@@ -128,13 +142,15 @@ def laurent_embed(nvar, topdim, pols, precision='d'):
     The default *precision* of the coefficients is 'd', for standard double
     precision.  For double double and quad double precision, set the value
     of *precision* to 'dd' or 'qd' respectively.
+    If *verbose_level* is larger than 0, then the names of the procedures
+    called in the running of the embed procedure will be listed.
     """
     if(precision == 'd'):
-        return standard_laurent_embed(nvar, topdim, pols)
+        return standard_laurent_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'dd'):
-        return dobldobl_laurent_embed(nvar, topdim, pols)
+        return dobldobl_laurent_embed(nvar, topdim, pols, verbose_level)
     elif(precision == 'qd'):
-        return quaddobl_laurent_embed(nvar, topdim, pols)
+        return quaddobl_laurent_embed(nvar, topdim, pols, verbose_level)
     else:
         print('wrong argument for precision')
         return None
